==> vcd-cli-19.2.2.dev33.tar.gz: vcd-cli-19.2.2.dev33/docs/commands.md <==
<div class="clt">
<ul><li>
<a href="vcd">vcd</a><ul><li>
<a href="vcd_catalog">catalog</a><ul><li>
<a href="vcd_catalog_create">create</a></li><li>
<a href="vcd_catalog_delete">delete</a></li><li>
<a href="vcd_catalog_download">download</a></li><li>
<a href="vcd_catalog_info">info</a></li><li>
<a href="vcd_catalog_list">list</a></li><li>
<a href="vcd_catalog_share">share</a></li><li>
<a href="vcd_catalog_unshare">unshare</a></li><li>
<a href="vcd_catalog_upload">upload</a></li>
</ul></li>
<li>
<a href="vcd_cluster">cluster</a><ul><li>
<a href="vcd_cluster_config">config</a></li><li>
<a href="vcd_cluster_create">create</a></li><li>
<a href="vcd_cluster_delete">delete</a></li><li>
<a href="vcd_cluster_list">list</a></li><li>
<a href="vcd_cluster_save-config">save-config</a></li>
</ul></li>
<li>
<a href="vcd_disk">disk</a><ul><li>
<a href="vcd_disk_create">create</a></li><li>
<a href="vcd_disk_delete">delete</a></li><li>
<a href="vcd_disk_info">info</a></li><li>
<a href="vcd_disk_list">list</a></li><li>
<a href="vcd_disk_update">update</a></li>
</ul></li>
<li>
<a href="vcd_help">help</a></li><li>
<a href="vcd_info">info</a></li><li>
<a href="vcd_login">login</a></li><li>
<a href="vcd_logout">logout</a></li><li>
<a href="vcd_org">org</a><ul><li>
<a href="vcd_org_info">info</a></li><li>
<a href="vcd_org_list">list</a></li><li>
<a href="vcd_org_use">use</a></li>
</ul></li>
<li>
<a href="vcd_profile">profile</a></li><li>
<a href="vcd_role">role</a><ul><li>
<a href="vcd_role_list">list</a></li>
</ul></li>
<li>
<a href="vcd_search">search</a></li><li>
<a href="vcd_system">system</a><ul><li>
<a href="vcd_system_amqp">amqp</a><ul><li>
<a href="vcd_system_amqp_info">info</a></li><li>
<a href="vcd_system_amqp_set">set</a></li><li>
<a href="vcd_system_amqp_test">test</a></li>
</ul></li>
<li>
<a href="vcd_system_extension">extension</a><ul><li>
<a href="vcd_system_extension_create">create</a></li><li>
<a href="vcd_system_extension_delete">delete</a></li><li>
<a href="vcd_system_extension_info">info</a></li><li>
<a href="vcd_system_extension_list">list</a></li>
</ul></li>
<li>
<a href="vcd_system_info">info</a></li>
</ul></li>
<li>
<a href="vcd_task">task</a><ul><li>
<a href="vcd_task_info">info</a></li><li>
<a href="vcd_task_list">list</a></li><li>
<a href="vcd_task_update">update</a></li><li>
<a href="vcd_task_wait">wait</a></li>
</ul></li>
<li>
<a href="vcd_user">user</a><ul><li>
<a href="vcd_user_create">create</a></li>
</ul></li>
<li>
<a href="vcd_vapp">vapp</a><ul><li>
<a href="vcd_vapp_capture">capture</a></li><li>
<a href="vcd_vapp_create">create</a></li><li>
<a href="vcd_vapp_delete">delete</a></li><li>
<a href="vcd_vapp_info">info</a></li><li>
<a href="vcd_vapp_list">list</a></li><li>
<a href="vcd_vapp_power-off">power-off</a></li><li>
<a href="vcd_vapp_power-on">power-on</a></li><li>
<a href="vcd_vapp_shutdown">shutdown</a></li><li>
<a href="vcd_vapp_update-lease">update-lease</a></li>
</ul></li>
<li>
<a href="vcd_vdc">vdc</a><ul><li>
<a href="vcd_vdc_info">info</a></li><li>
<a href="vcd_vdc_list">list</a></li><li>
<a href="vcd_vdc_use">use</a></li>
</ul></li>
<li>
<a href="vcd_version">version</a></li><li>
<a href="vcd_vm">vm</a><ul><li>
<a href="vcd_vm_download">download</a></li><li>
<a href="vcd_vm_info">info</a></li><li>
<a href="vcd_vm_list">list</a></li><li>
<a href="vcd_vm_run">run</a></li><li>
<a href="vcd_vm_upload">upload</a></li></ul>
</li></ul>
</li></ul>
</div>

==> vcd-cli-19.2.3.dev3.tar.gz: vcd-cli-19.2.3.dev3/docs/commands.md <==
<div class="clt">
<ul><li>
<a href="vcd">vcd</a><ul><li>
<a href="vcd_catalog">catalog</a><ul><li>
<a href="vcd_catalog_change-owner">change-owner</a></li><li>
<a href="vcd_catalog_control-access">control-access</a></li><li>
<a href="vcd_catalog_create">create</a></li><li>
<a href="vcd_catalog_delete">delete</a></li><li>
<a href="vcd_catalog_download">download</a></li><li>
<a href="vcd_catalog_info">info</a></li><li>
<a href="vcd_catalog_list">list</a></li><li>
<a href="vcd_catalog_share">share</a></li><li>
<a href="vcd_catalog_unshare">unshare</a></li><li>
<a href="vcd_catalog_update">update</a></li><li>
<a href="vcd_catalog_upload">upload</a></li>
</ul></li>
<li>
<a href="vcd_cluster">cluster</a><ul><li>
<a href="vcd_cluster_config">config</a></li><li>
<a href="vcd_cluster_create">create</a></li><li>
<a href="vcd_cluster_delete">delete</a></li><li>
<a href="vcd_cluster_list">list</a></li><li>
<a href="vcd_cluster_save-config">save-config</a></li>
</ul></li>
<li>
<a href="vcd_disk">disk</a><ul><li>
<a href="vcd_disk_change-owner">change-owner</a></li><li>
<a href="vcd_disk_create">create</a></li><li>
<a href="vcd_disk_delete">delete</a></li><li>
<a href="vcd_disk_info">info</a></li><li>
<a href="vcd_disk_list">list</a></li><li>
<a href="vcd_disk_update">update</a></li>
</ul></li>
<li>
<a href="vcd_help">help</a></li><li>
<a href="vcd_info">info</a></li><li>
<a href="vcd_login">login</a></li><li>
<a href="vcd_logout">logout</a></li><li>
<a href="vcd_org">org</a><ul><li>
<a href="vcd_org_create">create</a></li><li>
<a href="vcd_org_info">info</a></li><li>
<a href="vcd_org_list">list</a></li><li>
<a href="vcd_org_use">use</a></li>
</ul></li>
<li>
<a href="vcd_profile">profile</a></li><li>
<a href="vcd_role">role</a><ul><li>
<a href="vcd_role_list">list</a></li>
</ul></li>
<li>
<a href="vcd_search">search</a></li><li>
<a href="vcd_system">system</a><ul><li>
<a href="vcd_system_amqp">amqp</a><ul><li>
<a href="vcd_system_amqp_info">info</a></li><li>
<a href="vcd_system_amqp_set">set</a></li><li>
<a href="vcd_system_amqp_test">test</a></li>
</ul></li>
<li>
<a href="vcd_system_extension">extension</a><ul><li>
<a href="vcd_system_extension_create">create</a></li><li>
<a href="vcd_system_extension_delete">delete</a></li><li>
<a href="vcd_system_extension_info">info</a></li><li>
<a href="vcd_system_extension_list">list</a></li>
</ul></li>
<li>
<a href="vcd_system_info">info</a></li>
</ul></li>
<li>
<a href="vcd_task">task</a><ul><li>
<a href="vcd_task_info">info</a></li><li>
<a href="vcd_task_list">list</a></li><li>
<a href="vcd_task_update">update</a></li><li>
<a href="vcd_task_wait">wait</a></li>
</ul></li>
<li>
<a href="vcd_user">user</a><ul><li>
<a href="vcd_user_create">create</a></li><li>
<a href="vcd_user_delete">delete</a></li>
</ul></li>
<li>
<a href="vcd_vapp">vapp</a><ul><li>
<a href="vcd_vapp_add-disk">add-disk</a></li><li>
<a href="vcd_vapp_attach">attach</a></li><li>
<a href="vcd_vapp_capture">capture</a></li><li>
<a href="vcd_vapp_change-owner">change-owner</a></li><li>
<a href="vcd_vapp_create">create</a></li><li>
<a href="vcd_vapp_delete">delete</a></li><li>
<a href="vcd_vapp_detach">detach</a></li><li>
<a href="vcd_vapp_info">info</a></li><li>
<a href="vcd_vapp_list">list</a></li><li>
<a href="vcd_vapp_power-off">power-off</a></li><li>
<a href="vcd_vapp_power-on">power-on</a></li><li>
<a href="vcd_vapp_shutdown">shutdown</a></li><li>
<a href="vcd_vapp_update-lease">update-lease</a></li>
</ul></li>
<li>
<a href="vcd_vdc">vdc</a><ul><li>
<a href="vcd_vdc_info">info</a></li><li>
<a href="vcd_vdc_list">list</a></li><li>
<a href="vcd_vdc_use">use</a></li>
</ul></li>
<li>
<a href="vcd_version">version</a></li><li>
<a href="vcd_vm">vm</a><ul><li>
<a href="vcd_vm_download">download</a></li><li>
<a href="vcd_vm_info">info</a></li><li>
<a href="vcd_vm_list">list</a></li><li>
<a href="vcd_vm_run">run</a></li><li>
<a href="vcd_vm_upload">upload</a></li></ul>
</li></ul>
</li></ul>
</div>
